#[non_exhaustive]pub enum Error {
Show 26 variants
RemoteError(RemoteError),
GLibError(Error),
ImageSource(Error),
NixError(Errno),
StdIoError {
err: Arc<Error>,
info: String,
},
DbusError(Error),
InternalCommunicationCanceled,
NoLoadersConfigured(Config),
UnknownImageFormat(String, Config),
UnknownContentType(String),
PrematureExit {
status: ExitStatus,
cmd: String,
},
ConversionTooLargerError,
SpawnError {
cmd: String,
err: Arc<Error>,
},
SpawnErrorNotFound {
cmd: String,
err: Arc<Error>,
},
TextureWrongSize {
texture_size: usize,
frame: String,
},
TextureTooLarge,
StrideTooSmall(String),
WidgthOrHeightZero(String),
MemFd(Arc<Error>),
Seccomp(Arc<SeccompError>),
IccProfile(Error),
Canceled(Option<String>),
Editing(Error),
TransferredStream,
MathError(MathError),
CommonError(Error),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RemoteError(RemoteError)
GLibError(Error)
ImageSource(Error)
NixError(Errno)
StdIoError
DbusError(Error)
InternalCommunicationCanceled
NoLoadersConfigured(Config)
UnknownImageFormat(String, Config)
UnknownContentType(String)
PrematureExit
ConversionTooLargerError
SpawnError
SpawnErrorNotFound
TextureWrongSize
TextureTooLarge
StrideTooSmall(String)
WidgthOrHeightZero(String)
MemFd(Arc<Error>)
Seccomp(Arc<SeccompError>)
IccProfile(Error)
Canceled(Option<String>)
Editing(Error)
TransferredStream
MathError(MathError)
CommonError(Error)
Implementations
Sourceimpl Error
impl Error
Sourcepub fn unsupported_format(&self) -> Option<String>
pub fn unsupported_format(&self) -> Option<String>
Returns if the error is related to unsupported formats.
Return the mime type of the unsupported format or None if the error
is unrelated to unsupported formats.
pub fn is_out_of_memory(&self) -> bool
pub fn is_no_more_frames(&self) -> bool