pub enum SparseEdit {
Sparse(ByteChanges),
Complete(BinaryData),
}Expand description
An image change that is potentially sparse.
See also: [Editor::apply_sparse()]
Variants
Sparse(ByteChanges)
The operations can be applied to the image via only changing a few
bytes. The apply_to() function can be used to
apply these changes.
Complete(BinaryData)
The operations require to completely rewrite the image.
Implementations
Sourceimpl SparseEdit
impl SparseEdit
Sourcepub async fn apply_to(&self, file: File) -> Result<EditOutcome, Error>
pub async fn apply_to(&self, file: File) -> Result<EditOutcome, Error>
Apply sparse changes if applicable.
If the type does not carry sparse changes, the function will return an
EditOutcome::Unchanged and the complete image needs to be rewritten.