pub struct Frame { /* private fields */ }Expand description
A frame of an image often being the complete image
Implementations
Sourceimpl Frame
impl Frame
pub fn buf_bytes(&self) -> Bytes
pub fn buf_slice(&self) -> &[u8] ⓘ
pub fn memory_format(&self) -> MemoryFormat
pub fn color_state(&self) -> &ColorState
Sourcepub fn delay(&self) -> Option<Duration>
pub fn delay(&self) -> Option<Duration>
Duration to show frame for animations.
If the value is not set, the image is not animated.
pub fn details(&self) -> FrameDetails
pub fn texture(&self) -> Texture