pub struct PoolConfig { /* private fields */ }Expand description
Pool configuration
Implementations
Sourceimpl PoolConfig
impl PoolConfig
Sourcepub fn new() -> PoolConfig
pub fn new() -> PoolConfig
Default pool configuration. See below for default values.
Sourcepub fn max_parallel_operations(
self,
max_parallel_operations: usize,
) -> PoolConfig
pub fn max_parallel_operations( self, max_parallel_operations: usize, ) -> PoolConfig
Maximum of operations one process will be tasked with. The default value
is usize::MAX.
Sourcepub fn retention_time(self, retention_time: Duration) -> PoolConfig
pub fn retention_time(self, retention_time: Duration) -> PoolConfig
Time after last use after which a processor process will be terminated. The default value is 30 seconds.