#[repr(i32)]pub enum SandboxSelector {
Auto = 0,
Bwrap = 1,
FlatpakSpawn = 2,
NotSandboxed = 3,
}Expand description
Method by which the SandboxMechanism is selected
Variants
Auto = 0
This mode selects bwrap outside of Flatpaks and usually
flatpak-spawn inside of Flatpaks. The sandbox is disabled
automatically inside of Flatpak development environments. See
details below.
Inside of Flatpaks, flatpak-spawn is used to create the sandbox. This
mechanism starts an installed Flatpak with the same app id. For
development, Flatpak are usually not installed and the sandbox can
therefore not be used. If the sandbox has been started via
flatpak-builder --run (i.e. without installed Flatpak) and the app id
ends with Devel, the sandbox is disabled.
Bwrap = 1
FlatpakSpawn = 2
NotSandboxed = 3
Implementations
Sourceimpl SandboxSelector
impl SandboxSelector
pub async fn determine_sandbox_mechanism(self) -> SandboxMechanism